pub fn init_behaviors()Expand description
Initializes the global behavior registries.
This should be called after the main registry is frozen. Repeated calls are a no-op.
pub fn init_behaviors()Initializes the global behavior registries.
This should be called after the main registry is frozen. Repeated calls are a no-op.