BlockLootContext

Struct BlockLootContext 

pub struct BlockLootContext<'a> {
    world: &'a Arc<World>,
    pos: BlockPos,
    entity: Option<&'a dyn Entity>,
    tool: Option<&'a ItemStack>,
    luck: f32,
}
Live parameters used to resolve a block’s loot.

This is the Steel counterpart to vanilla’s block LootParams. Behaviors can override loot generation while retaining the original tool, entity, luck, and position when delegating to another block state.

Fields

world: &'a Arc<World>pos: BlockPosentity: Option<&'a dyn Entity>tool: Option<&'a ItemStack>luck: f32

Implementations

Source

impl<'a> BlockLootContext<'a>

pub const fn new(world: &'a Arc<World>, pos: BlockPos) -> Self

Creates a no-tool block loot context.

pub const fn with_entity(self, entity: Option<&'a dyn Entity>) -> Self

Adds the entity responsible for destroying the block.

pub const fn with_tool(self, tool: &'a ItemStack) -> Self

Adds the tool used to destroy the block.

pub const fn with_luck(self, luck: f32) -> Self

Adds the luck used to evaluate the loot table.

pub const fn world(&self) -> &'a Arc<World>

Returns the world containing the block.

pub const fn pos(&self) -> BlockPos

Returns the block position whose loot is being resolved.

pub fn get_drops(&self, state: BlockStateId) -> Vec<ItemStack>

Resolves loot for another state with the same vanilla loot parameters.

pub(crate) const fn entity(&self) -> Option<&'a dyn Entity>

pub(crate) const fn tool(&self) -> Option<&'a ItemStack>

pub(crate) const fn luck(&self) -> f32